==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/RecurrenceScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.RecurrenceScheduleArgs.builder
import com.pulumi.azurenative.logic.kotlin.enums.DaysOfWeek
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The recurrence schedule.
 * @property hours The hours.
 * @property minutes The minutes.
 * @property monthDays The month days.
 * @property monthlyOccurrences The monthly occurrences.
 * @property weekDays The days of the week.
 */
public data class RecurrenceScheduleArgs(
    public val hours: Output<List<Int>>? = null,
    public val minutes: Output<List<Int>>? = null,
    public val monthDays: Output<List<Int>>? = null,
    public val monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null,
    public val weekDays: Output<List<DaysOfWeek>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.RecurrenceScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.RecurrenceScheduleArgs =
        com.pulumi.azurenative.logic.inputs.RecurrenceScheduleArgs.builder()
            .hours(hours?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .minutes(minutes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthDays(monthDays?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthlyOccurrences(
                monthlyOccurrences?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .weekDays(
                weekDays?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RecurrenceScheduleArgs].
 */
@PulumiTagMarker
public class RecurrenceScheduleArgsBuilder internal constructor() {
    private var hours: Output<List<Int>>? = null

    private var minutes: Output<List<Int>>? = null

    private var monthDays: Output<List<Int>>? = null

    private var monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null

    private var weekDays: Output<List<DaysOfWeek>>? = null

    /**
     * @param value The hours.
     */
    @JvmName("adduqtigorbllcqb")
    public suspend fun hours(`value`: Output<List<Int>>) {
        this.hours = value
    }

    @JvmName("knoestgygtotadex")
    public suspend fun hours(vararg values: Output<Int>) {
        this.hours = Output.all(values.asList())
    }

    /**
     * @param values The hours.
     */
    @JvmName("pehfnfwdxnlxryua")
    public suspend fun hours(values: List<Output<Int>>) {
        this.hours = Output.all(values)
    }

    /**
     * @param value The minutes.
     */
    @JvmName("rcogttjmmqssdarj")
    public suspend fun minutes(`value`: Output<List<Int>>) {
        this.minutes = value
    }

    @JvmName("htwgbxmkkvnqyvvs")
    public suspend fun minutes(vararg values: Output<Int>) {
        this.minutes = Output.all(values.asList())
    }

    /**
     * @param values The minutes.
     */
    @JvmName("ovketohatiosnmmn")
    public suspend fun minutes(values: List<Output<Int>>) {
        this.minutes = Output.all(values)
    }

    /**
     * @param value The month days.
     */
    @JvmName("mpntswnlvkkielgu")
    public suspend fun monthDays(`value`: Output<List<Int>>) {
        this.monthDays = value
    }

    @JvmName("rwrohspsaphplxgw")
    public suspend fun monthDays(vararg values: Output<Int>) {
        this.monthDays = Output.all(values.asList())
    }

    /**
     * @param values The month days.
     */
    @JvmName("txvykiybiwyapwut")
    public suspend fun monthDays(values: List<Output<Int>>) {
        this.monthDays = Output.all(values)
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("qrbvhxyxjvqicltd")
    public suspend fun monthlyOccurrences(`value`: Output<List<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = value
    }

    @JvmName("lkmbyyyuonwtskts")
    public suspend fun monthlyOccurrences(vararg values: Output<RecurrenceScheduleOccurrenceArgs>) {
        this.monthlyOccurrences = Output.all(values.asList())
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("jwcxajajqybiomrl")
    public suspend fun monthlyOccurrences(values: List<Output<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = Output.all(values)
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("nsjheykbfbexghfy")
    public suspend fun weekDays(`value`: Output<List<DaysOfWeek>>) {
        this.weekDays = value
    }

    @JvmName("jabpvgcqykymxsah")
    public suspend fun weekDays(vararg values: Output<DaysOfWeek>) {
        this.weekDays = Output.all(values.asList())
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("pajrtrpcnbqrrvcw")
    public suspend fun weekDays(values: List<Output<DaysOfWeek>>) {
        this.weekDays = Output.all(values)
    }

    /**
     * @param value The hours.
     */
    @JvmName("kgljcsxhxwyvpfch")
    public suspend fun hours(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param values The hours.
     */
    @JvmName("ypexacdydigsxakk")
    public suspend fun hours(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param value The minutes.
     */
    @JvmName("ycvcxosnyjkxetho")
    public suspend fun minutes(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param values The minutes.
     */
    @JvmName("qtskcrjrpfhecewt")
    public suspend fun minutes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param value The month days.
     */
    @JvmName("cwybuijefoecncrd")
    public suspend fun monthDays(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param values The month days.
     */
    @JvmName("jvmsbjdivaltjupu")
    public suspend fun monthDays(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("itagvwtadoesvcsa")
    public suspend fun monthlyOccurrences(`value`: List<RecurrenceScheduleOccurrenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("gjnbkvctsxkbrqwh")
    public suspend
    fun monthlyOccurrences(argument: List<suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("ycttkvydtgrtgjct")
    public suspend fun monthlyOccurrences(
        vararg
        argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("aqejvudcdybhmixp")
    public suspend
    fun monthlyOccurrences(argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("myblldwvhfbrarjt")
    public suspend fun monthlyOccurrences(vararg values: RecurrenceScheduleOccurrenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("nlkwovjsqowocepg")
    public suspend fun weekDays(`value`: List<DaysOfWeek>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("rifwjwcljrmdlcih")
    public suspend fun weekDays(vararg values: DaysOfWeek) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    internal fun build(): RecurrenceScheduleArgs = RecurrenceScheduleArgs(
        hours = hours,
        minutes = minutes,
        monthDays = monthDays,
        monthlyOccurrences = monthlyOccurrences,
        weekDays = weekDays,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/RecurrenceScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.RecurrenceScheduleArgs.builder
import com.pulumi.azurenative.logic.kotlin.enums.DaysOfWeek
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Int
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The recurrence schedule.
 * @property hours The hours.
 * @property minutes The minutes.
 * @property monthDays The month days.
 * @property monthlyOccurrences The monthly occurrences.
 * @property weekDays The days of the week.
 */
public data class RecurrenceScheduleArgs(
    public val hours: Output<List<Int>>? = null,
    public val minutes: Output<List<Int>>? = null,
    public val monthDays: Output<List<Int>>? = null,
    public val monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null,
    public val weekDays: Output<List<DaysOfWeek>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.RecurrenceScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.RecurrenceScheduleArgs =
        com.pulumi.azurenative.logic.inputs.RecurrenceScheduleArgs.builder()
            .hours(hours?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .minutes(minutes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthDays(monthDays?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .monthlyOccurrences(
                monthlyOccurrences?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .weekDays(
                weekDays?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [RecurrenceScheduleArgs].
 */
@PulumiTagMarker
public class RecurrenceScheduleArgsBuilder internal constructor() {
    private var hours: Output<List<Int>>? = null

    private var minutes: Output<List<Int>>? = null

    private var monthDays: Output<List<Int>>? = null

    private var monthlyOccurrences: Output<List<RecurrenceScheduleOccurrenceArgs>>? = null

    private var weekDays: Output<List<DaysOfWeek>>? = null

    /**
     * @param value The hours.
     */
    @JvmName("rpoqnivgcabqmcux")
    public suspend fun hours(`value`: Output<List<Int>>) {
        this.hours = value
    }

    @JvmName("jswyowgrsdvnxvog")
    public suspend fun hours(vararg values: Output<Int>) {
        this.hours = Output.all(values.asList())
    }

    /**
     * @param values The hours.
     */
    @JvmName("jqrgmsouejenasaj")
    public suspend fun hours(values: List<Output<Int>>) {
        this.hours = Output.all(values)
    }

    /**
     * @param value The minutes.
     */
    @JvmName("mwmuclliuioetysp")
    public suspend fun minutes(`value`: Output<List<Int>>) {
        this.minutes = value
    }

    @JvmName("cvhvbydsrxttobua")
    public suspend fun minutes(vararg values: Output<Int>) {
        this.minutes = Output.all(values.asList())
    }

    /**
     * @param values The minutes.
     */
    @JvmName("jmjcvtwhmtydyaff")
    public suspend fun minutes(values: List<Output<Int>>) {
        this.minutes = Output.all(values)
    }

    /**
     * @param value The month days.
     */
    @JvmName("brvrqwnrpxccdaul")
    public suspend fun monthDays(`value`: Output<List<Int>>) {
        this.monthDays = value
    }

    @JvmName("gspqjsemdmujcegk")
    public suspend fun monthDays(vararg values: Output<Int>) {
        this.monthDays = Output.all(values.asList())
    }

    /**
     * @param values The month days.
     */
    @JvmName("ephgmxhppnceejcm")
    public suspend fun monthDays(values: List<Output<Int>>) {
        this.monthDays = Output.all(values)
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("wtlmudsqfqacmtbr")
    public suspend fun monthlyOccurrences(`value`: Output<List<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = value
    }

    @JvmName("uxphmiakwbpesnne")
    public suspend fun monthlyOccurrences(vararg values: Output<RecurrenceScheduleOccurrenceArgs>) {
        this.monthlyOccurrences = Output.all(values.asList())
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("hfepgdejcdqdmagl")
    public suspend fun monthlyOccurrences(values: List<Output<RecurrenceScheduleOccurrenceArgs>>) {
        this.monthlyOccurrences = Output.all(values)
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("mqsxpbychbtqldsm")
    public suspend fun weekDays(`value`: Output<List<DaysOfWeek>>) {
        this.weekDays = value
    }

    @JvmName("elyvmgnukluiyfsm")
    public suspend fun weekDays(vararg values: Output<DaysOfWeek>) {
        this.weekDays = Output.all(values.asList())
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("jbkvdkytvkgtbdqo")
    public suspend fun weekDays(values: List<Output<DaysOfWeek>>) {
        this.weekDays = Output.all(values)
    }

    /**
     * @param value The hours.
     */
    @JvmName("eqdekqqvxnhaombw")
    public suspend fun hours(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param values The hours.
     */
    @JvmName("wbnhjntfdqjryeju")
    public suspend fun hours(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hours = mapped
    }

    /**
     * @param value The minutes.
     */
    @JvmName("jaqpeoccimwujdwf")
    public suspend fun minutes(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param values The minutes.
     */
    @JvmName("ngpbbnigrkhnbmev")
    public suspend fun minutes(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.minutes = mapped
    }

    /**
     * @param value The month days.
     */
    @JvmName("ynpnubbgswuvccux")
    public suspend fun monthDays(`value`: List<Int>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param values The month days.
     */
    @JvmName("vxyyunryxesdqrjr")
    public suspend fun monthDays(vararg values: Int) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthDays = mapped
    }

    /**
     * @param value The monthly occurrences.
     */
    @JvmName("hxoexssjipdrtykq")
    public suspend fun monthlyOccurrences(`value`: List<RecurrenceScheduleOccurrenceArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("stcmjfithlsfhsxy")
    public suspend
    fun monthlyOccurrences(argument: List<suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("elpybcxshhkhbaui")
    public suspend fun monthlyOccurrences(
        vararg
        argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param argument The monthly occurrences.
     */
    @JvmName("brheycxkkgkpmofc")
    public suspend
    fun monthlyOccurrences(argument: suspend RecurrenceScheduleOccurrenceArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            RecurrenceScheduleOccurrenceArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.monthlyOccurrences = mapped
    }

    /**
     * @param values The monthly occurrences.
     */
    @JvmName("roncmcqbvsfbhbiq")
    public suspend fun monthlyOccurrences(vararg values: RecurrenceScheduleOccurrenceArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthlyOccurrences = mapped
    }

    /**
     * @param value The days of the week.
     */
    @JvmName("pnqwsxfrfimlimrg")
    public suspend fun weekDays(`value`: List<DaysOfWeek>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    /**
     * @param values The days of the week.
     */
    @JvmName("wenotccdlcjncruy")
    public suspend fun weekDays(vararg values: DaysOfWeek) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.weekDays = mapped
    }

    internal fun build(): RecurrenceScheduleArgs = RecurrenceScheduleArgs(
        hours = hours,
        minutes = minutes,
        monthDays = monthDays,
        monthlyOccurrences = monthlyOccurrences,
        weekDays = weekDays,
    )
}
